Struct Connection
pub struct Connection { /* private fields */ }wayland and Linux only.Expand description
The Wayland connection
This is the main type representing your connection to the Wayland server, though most of the interaction
with the protocol are actually done using other types. The two main uses a simple app has for the
Connection are:
- Obtaining the initial
WlDisplaythrough thedisplay()method. - Creating new
EventQueues with thenew_event_queue()method.
It can be created through the connect_to_env() method to follow the
configuration from the environment (which is what you’ll do most of the time), or using the
from_socket() method if you retrieved your connected Wayland socket through
other means.
In case you need to plug yourself into an external Wayland connection that you don’t control, you’ll
likely get access to it as a Backend, in which case you can create a Connection from it using
the from_backend() method.
Implementations
impl Connection
impl Connection
pub fn connect_to_env() -> Result<Connection, ConnectError>
pub fn connect_to_env() -> Result<Connection, ConnectError>
Try to connect to the Wayland server following the environment
This is the standard way to initialize a Wayland connection.
pub fn from_socket(stream: UnixStream) -> Result<Connection, ConnectError>
pub fn from_socket(stream: UnixStream) -> Result<Connection, ConnectError>
Initialize a Wayland connection from an already existing Unix stream
pub fn new_event_queue<State>(&self) -> EventQueue<State>
pub fn new_event_queue<State>(&self) -> EventQueue<State>
Create a new event queue
pub fn from_backend(backend: Backend) -> Connection
pub fn from_backend(backend: Backend) -> Connection
Wrap an existing Backend into a Connection
pub fn backend(&self) -> Backend
pub fn backend(&self) -> Backend
Get the Backend underlying this Connection
pub fn flush(&self) -> Result<(), WaylandError>
pub fn flush(&self) -> Result<(), WaylandError>
Flush pending outgoing events to the server
This needs to be done regularly to ensure the server receives all your requests, though several dispatching methods do it implicitly (this is stated in their documentation when they do).
pub fn prepare_read(&self) -> Option<ReadEventsGuard>
pub fn prepare_read(&self) -> Option<ReadEventsGuard>
Start a synchronized read from the socket
This is needed if you plan to wait on readiness of the Wayland socket using an event loop. See
ReadEventsGuard for details. Once the events are received, you’ll then need to dispatch them from
their event queues using EventQueue::dispatch_pending().
If you don’t need to manage multiple event sources, see
EventQueue::blocking_dispatch() for a simpler mechanism.
pub fn roundtrip(&self) -> Result<usize, WaylandError>
pub fn roundtrip(&self) -> Result<usize, WaylandError>
Do a roundtrip to the server
This method will block until the Wayland server has processed and answered all your preceding requests. This is notably useful during the initial setup of an app, to wait for the initial state from the server.
See EventQueue::roundtrip() for a version that includes the dispatching of the event queue.
pub fn protocol_error(&self) -> Option<ProtocolError>
pub fn protocol_error(&self) -> Option<ProtocolError>
Retrieve the protocol error that occured on the connection if any
If this method returns Some, it means your Wayland connection is already dead.
pub fn send_request<I>(
&self,
proxy: &I,
request: <I as Proxy>::Request<'_>,
data: Option<Arc<dyn ObjectData>>,
) -> Result<ObjectId, InvalidId>where
I: Proxy,
pub fn send_request<I>(
&self,
proxy: &I,
request: <I as Proxy>::Request<'_>,
data: Option<Arc<dyn ObjectData>>,
) -> Result<ObjectId, InvalidId>where
I: Proxy,
Send a request associated with the provided object
This is a low-level interface used by the code generated by wayland-scanner, you will likely
instead use the methods of the types representing each interface, or the Proxy::send_request() and
Proxy::send_constructor().
pub fn object_info(&self, id: ObjectId) -> Result<ObjectInfo, InvalidId>
pub fn object_info(&self, id: ObjectId) -> Result<ObjectInfo, InvalidId>
Get the protocol information related to given object ID
pub fn get_object_data(
&self,
id: ObjectId,
) -> Result<Arc<dyn ObjectData>, InvalidId>
pub fn get_object_data( &self, id: ObjectId, ) -> Result<Arc<dyn ObjectData>, InvalidId>
Get the object data for a given object ID
This is a low-level interface used by the code generated by wayland-scanner, a higher-level
interface for manipulating the user-data assocated to Dispatch implementations
is given as Proxy::data(). Also see Proxy::object_data().