Struct QueueHandle
pub struct QueueHandle<State> { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
A handle representing an EventQueue, used to assign objects upon creation.
Implementations
impl<State> QueueHandle<State>where
State: 'static,
impl<State> QueueHandle<State>where
State: 'static,
pub fn make_data<I, U>(&self, user_data: U) -> Arc<dyn ObjectData>
pub fn make_data<I, U>(&self, user_data: U) -> Arc<dyn ObjectData>
Create an object data associated with this event queue
This creates an implementation of ObjectData fitting for direct use with wayland-backend APIs
that forwards all events to the event queue associated with this token, integrating the object into
the Dispatch-based logic of wayland-client.
pub fn freeze(&self) -> QueueFreezeGuard<'_, State>
pub fn freeze(&self) -> QueueFreezeGuard<'_, State>
Temporarily block processing on this queue.
This will cause the associated queue to block (or return NotReady to poll) until all
QueueFreezeGuards associated with the queue are dropped.