Struct Weak

pub struct Weak<I> { /* private fields */ }
Available on crate feature wayland and Linux only.
A weak handle to a Wayland object

This handle does not keep the underlying user data alive, and can be converted back to a full proxy using Weak::upgrade().

Implementations



impl<I> Weak<I>
where I: Proxy,

pub fn upgrade(&self) -> Result<I, InvalidId>

Try to upgrade with weak handle back into a full proxy.

This will fail if either:

  • the object represented by this handle has already been destroyed at the protocol level
  • the Wayland connection has already been closed

pub fn id(&self) -> ObjectId

The underlying ObjectId