Struct Weak
pub struct Weak<I> { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
A weak handle to a Wayland object
This handle does not keep the underlying user data alive, and can be converted back to a full proxy
using Weak::upgrade().
Implementations